@@ -1,35 +1,25 @@
-# -*- coding: utf-8 -*-
-"""
-plone.app.z3cform
-
-Licensed under the GPL license, see LICENCE.txt for more details.
-
-$Id: test_kss_attr.py 22262 2008-08-18 21:20:25Z optilude $
-"""
-from Products.PloneTestCase import PloneTestCase as ptc
-from kss.core.BeautifulSoup import BeautifulSoup
 from Testing import ZopeTestCase as ztc
-from Products.PloneTestCase.layer import PloneSite
+from Products.PloneTestCase import ptc
 from Products.Five.testbrowser import Browser
-from Products.Five import zcml
-import plone.app.z3cform
 
+from kss.core.BeautifulSoup import BeautifulSoup
+
+from plone.app.z3cform.tests.layer import IntegrationLayer
 
 class TestKSSAttributes(ptc.FunctionalTestCase):
+    
+    layer = IntegrationLayer
+    
     BeautifulSoup = BeautifulSoup
 
     def afterSetUp(self):
-        zcml.load_config('testing.zcml', plone.app.z3cform.tests)
-        zcml.load_config('configure.zcml', plone.app.z3cform)
         self.user = ptc.default_user
         self.password = ptc.default_password
         self.browser = Browser()
         self.browser.handleErrors = False
 
-
 def test_form():
     r"""
-
         >>> self.browser.addHeader(
         ...    'Authorization', 'Basic %s:%s' % (self.user, self.password))
         >>> self.browser.open(self.folder.absolute_url() + '/test-form')
@@ -37,7 +27,7 @@ def test_form():
     Let's see if the kss-attr formname is actually on the form:
 
         >>> soup = self.BeautifulSoup(self.browser.contents)
-        >>> div = soup.find('div', id="skel-contents")
+        >>> div = soup.find('div', id="content-core")
         >>> form = div.form
         >>> 'kssattr-formname-test-form' in form['class']
         True
@@ -50,7 +40,7 @@ def test_form():
     let's see if widget have the right class:
 
         >>> soup = self.BeautifulSoup(self.browser.contents)
-        >>> soup.find('div',{'class':'widget z3cformInlineValidation horizontal'}) is not None
+        >>> soup.find('div',{'class':'field z3cformInlineValidation kssattr-fieldname-form.widgets.age'}) is not None
         True
     """
 
@@ -63,7 +53,7 @@ def test_group_form():
     Let's see if the kss-attr formname is actually on the form:
 
         >>> soup = self.BeautifulSoup(self.browser.contents)
-        >>> div = soup.find('div', id="skel-contents")
+        >>> div = soup.find('div', id="content-core")
         >>> form = div.form
         >>> 'kssattr-formname-test-group-form' in form['class']
         True
@@ -103,12 +93,10 @@ def test_group_form():
     let's see if widget have the right class:
 
         >>> soup = self.BeautifulSoup(self.browser.contents)
-        >>> soup.find('div',{'class':'widget z3cformInlineValidation horizontal'}) is not None
+        >>> soup.find('div',{'class':'field z3cformInlineValidation kssattr-fieldname-form.widgets.name'}) is not None
         True
     """
 
-
 def test_suite():
     suite = ztc.FunctionalDocTestSuite(test_class=TestKSSAttributes)
-    suite.layer = PloneSite
     return suite
